@@ -2,7 +2,7 @@ package DBIx::Skinny::Schema::Loader;
 use strict;
 use warnings;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use Carp;
 use DBI;
@@ -39,6 +39,8 @@ sub supported_drivers {
 
 sub connect {
     my $self = shift;
+    return if defined $self->{ impl };
+
     my $opts;
     if (@_ == 1) {
         $opts = +{
@@ -96,12 +98,14 @@ sub get_skinny_connect_info {
 }
 
 sub make_schema_at {
+    my $self = (ref $_[0] eq 'DBIx::Skinny::Schema::Loader') ? shift : __PACKAGE__->new;
     my ($schema_class, $options, $connect_info) = @_;
 
-    my $self = __PACKAGE__->new;
     $self->connect(ref $connect_info eq 'HASH' ? $connect_info : @{ $connect_info });
 
-    my $schema = "package $schema_class;\nuse DBIx::Skinny::Schema;\n\n";
+    my $schema = $self->_insert_header;
+    $schema .= "package $schema_class;\nuse DBIx::Skinny::Schema;\n\n";
+
     $schema .= $self->_insert_template($options->{ before_template });
     $schema .= $self->_insert_template($options->{ template });
     $schema .= $self->_make_install_table_text(
@@ -113,15 +117,23 @@ sub make_schema_at {
         $options->{ table_template }
     ) for @{ $self->_get_tables($options->{ ignore_rules }) };
     $schema .= $self->_insert_template($options->{ after_template });
+
     $schema .= "1;";
     return $schema;
 }
 
+sub _insert_header {
+    "# THIS FILE IS AUTOGENERATED BY DBIx::Skinny::Schema::Loader $VERSION, DO NOT EDIT DIRECTLY.\n\n";
+}
+
 sub _insert_template {
     my ($self, $template) = @_;
     return '' unless $template;
     chomp $template;
-    return $template . "\n\n";
+
+    "# ---- beginning of custom template ----\n" .
+    $template . "\n" .
+    "# ---- end of custom template ----\n\n";
 }
 
 sub _make_install_table_text {
@@ -305,7 +317,6 @@ insert your custom template before install_table block.
       $args->{ created_at } ||= DateTime->now;
     }
   }
-  ...
 
   print make_schema_at(
       'Your::DB::Schema',
@@ -331,6 +342,8 @@ after_template inserts template after install_table block.
       [ 'dbi:SQLite:test.db', '', '' ]
   );
 
+there are more detailed example in C<$before_template> section.
+
 you can use both before_template and after_template all together.
 
 =head2 template
